@@ -21,7 +21,7 @@ describe RSpec::Retry do
 
   context 'no retry option' do
     it 'should work' do
-      true.should be_true
+      true.should be true
     end
   end
 
@@ -45,10 +45,6 @@ describe RSpec::Retry do
         count.should == 2
       end
     end
-
-    it 'should success randomly', :retry => 3 do
-      rand(3).should == 1
-    end
   end
 
   describe 'clearing lets' do
